require('math')
local sti = require('sti')
require('/lib/TEsound')

-- Constants
translateX = 64
translateY = 64
-- Timers
canJump = true
 canJumpTimerMax = 1  
canJumpTimer = canJumpTimerMax

function love.load()
	-- Graphics Settings
	love.window.setMode(0, 0, {fullscreen = true, vsync = true})
	windowWidth = love.graphics.getWidth()
	windowHeight = love.graphics.getHeight()
	love.graphics.setBackgroundColor(135, 206, 235)
	love.graphics.setDefaultFilter('nearest', 'nearest')

	-- World Stuff
	map = sti.new("assets/maps/map-01")
	local CollideLayer = map.layers["Collide"]
	CollideLayer.visible = false

	love.physics.setMeter(32)
	world = love.physics.newWorld(0, 9.81*32)
	collision = map:initWorldCollision(world)

	TEMPSPRITES = {player = {
		image = love.graphics.newImage("assets/sprites/player.png"),
		fixture = love.physics.newFixture(love.physics.newBody(world, 600, 800, 'dynamic'), love.physics.newRectangleShape( 16, 34, 18, 58))}
	}
	local body = TEMPSPRITES.player.fixture:getBody()
	body:setFixedRotation(true)



	map:addCustomLayer("Sprite Layer", 3)
	-- Prepare Sprites
	
	spriteLayer = map.layers["Sprite Layer"]
	spriteLayer.sprites=TEMPSPRITES

	-- Prepare Sounds
	jumpsound = love.sound.newSoundData('assets/sounds/jump.mp3')

	-- Update callback for Custom Layer
	function spriteLayer:update(dt)
		local player = self.sprites.player
		local body = player.fixture:getBody()
		contacts = body:getContactList()

		if love.keyboard.isDown('d', 'right')  and contacts[1] then
			body:applyForce(320, 0)
		end
		if love.keyboard.isDown('left', 'a')  and contacts[1] then
			body:applyForce(-320, 0)
		end
		if love.keyboard.isDown(' ') and canJump and contacts[1] then
			TEsound.play(jumpsound, '', 0.05)
			body:applyLinearImpulse(0, -300)
			canJump = false
			canJumpTimer = canJumpTimerMax
		end

		local x, y = body:getPosition()
		translateX = 200 + x * -1
		translateY = 150 + y * -1
	end

	-- Draw callback for Custom Layer
	function spriteLayer:draw()
		local player = self.sprites.player
		local body = player.fixture:getBody()
		local x, y = body:getPosition()
		local r = body:getAngle()
		local vx, vy = body:getLinearVelocity()
		local side = 1
		local adjust = 0

		if vx <= 0 then
			side = -1
			adjust = 32
		end

		if vx >= 0 then
			side = 1
			adjust = 0
		end

		if love.keyboard.isDown('d', 'right') then
			side = 1
			adjust = 0
		end

		if love.keyboard.isDown('a', 'left') then
			side = -1
			adjust = 32
		end

		love.graphics.draw(player.image, x + adjust, y, r, side, 1)
	end
end


function love.update(dt)
	canJumpTimer = canJumpTimer - (1 * dt)
	if canJumpTimer < 0 then
		canJump = true
	end
	world:update(dt)
	map:update(dt)
end

function love.draw()
	love.graphics.scale(3.3,3.3)
	local width = love.graphics.getWidth()
	local height = love.graphics.getHeight()
	love.graphics.translate(translateX, translateY)
	map:setDrawRange(translateX, translateY, width, height)
	map:draw()
	--map:drawWorldCollision(collision)
end

function love.resize(w, h)
	map:resize(w, h)
end